# fishtank

[![Build Status](https://travis-ci.org/openuado/fishtank.svg?branch=master)](https://travis-ci.org/openuado/fishtank)
![PyPI](https://img.shields.io/pypi/v/fishtank.svg)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/fishtank.svg)
![PyPI - Status](https://img.shields.io/pypi/status/fishtank.svg)

Command line interface (CLI) for redfish

## Contribute

If you want to contribute to fishtank [please first read the contribution guidelines](CONTRIBUTING.md)

## Licence

This project is under the MIT License.

[See the license file for more details](LICENSE)
